.. note::

   Also see the `release notes <https://scanpy.readthedocs.io>`__ of :mod:`scanpy`.
   
   Also see the `release notes <https://anndata.readthedocs.io>`__ of :mod:`anndata`.


.. role:: small

.. role:: smaller



Version 0.2.0 :small:`August 7, 2020`
--------------------------------------

This release deal with the compatibility problems with the latest version of scanpy. 
Additionally, it contains new features to build quick custom count matrices (bld_mtx_fly),
to convert snap into h5ad files (snap2anndata) or build gene activity matrices (geneactivity).


Version 0.1.8 :small:`November 5, 2019`
--------------------------------------

Release new processing function & quality controls. 




Version 0.1.7 :small:`November 5, 2019`
--------------------------------------

Release for SCOG epiScanpy Hackathon in Saarbrucken.

This version is not fully compatible with previous version. 


Version 0.1.0 :small:`May 10, 2019`
--------------------------------------

Initial release.
